#include "tg_common.glsl"

#ifdef _FRAGMENT_

//-----------------------------------------------------------------------------

float   GlowMapSun(vec3 point)
{
    float hillsFreqReplace = hillsFreq;
    float dunesMagnReplace = dunesMagn;
    float flatHills = 1.0;
    float flowsMult = 0.1;
    float granNoise = 5.0;
    
    if ((dunesMagn >= 1.0) || (hillsMagn >= 1.0))       // Changed sun shader
    {
        // Makes freckles
        // float hillsFreqReplace = hillsFreq;
        hillsFreqReplace = (hillsFreq <= 1.0 ) ? 1.0 : hillsFreq;
        dunesMagnReplace = 1.5;
        // Flattens freckles
        //flatHills = 1.0;
        flatHills = 1.0 / hillsFreqReplace;
        flowsMult = 0.3;
        granNoise = 3.0;
    }
    
    // Flows
    noiseOctaves = 5;
    vec3  p = point * max(1.0, colorDistFreq) + Randomize;            // *** That's what matters.*** 
    // vec3  p = point * colorDistFreq + Randomize;
    vec3  dist = 2.5 * Fbm3D(p * 0.5);
    noiseOctaves = 3;
    float flows = Fbm(p * 7.5 + dist);
    
    // Granularity
    noiseOctaves = granNoise;
    p = point * hillsFreqReplace * flatHills + Randomize;
    dist = dunesMagnReplace * Fbm3D(p * 0.2);
    vec2  cell = Cell3Noise2(p + dist);
    float gran = smoothstep(0.1, 1.0, sqrt(abs(cell.y - cell.x)));

    // Solar spots
    float botMask = 1.0;
    float filMask = 0.0;
    float filaments = 0.0;
    if (mareSqrtDensity > 0.01)
    {
        noiseOctaves = 5;
        SolarSpotsTempNoise(point, botMask, filMask, filaments);
    }

    float granTopTemp = colorParams.z;
    float granBotTemp = colorParams.w;
    float surfTemp = 1.0;
    float filTemp  = granTopTemp;
    float spotTemp = granBotTemp;

    // return (flows * 0.1 + mix(granBotTemp, granTopTemp, gran) * (1.0 - filMask)) * mix(spotTemp, surfTemp, botMask) + filMask * mix(spotTemp, filTemp, filaments);
        return (flows * flowsMult + mix(granBotTemp, granTopTemp, gran) * (1.0 - filMask)) * mix(spotTemp, surfTemp, botMask) + filMask * mix(spotTemp, filTemp, filaments);
}

//-----------------------------------------------------------------------------

void main()
{
    vec3  point = GetSurfacePoint();
    float surfTemp = GlowMapSun(point);
    surfTemp *= surfTemperature; // in thousand Kelvins
    OutColor.rgb = UnitToColor24(log(surfTemp) * 0.188 + 0.1316);
    OutColor.a = 1.0;
}

//-----------------------------------------------------------------------------

#endif
