#include "tg_common.glsl"

#ifdef _FRAGMENT_

//-----------------------------------------------------------------------------

float   HeightMapSun(vec3 point)
{
    float hillsFreqReplace = hillsFreq;
    float dunesMagnReplace = dunesMagn;
    float hillsMagnReplace = hillsMagn;
    float flatHills = 1.0;
    float granNoise = 5.0;
    
    if ((dunesMagn >= 1.0) || (hillsMagn >= 1.0))           // Changed sun shader
    {
        // Makes freckles
        hillsFreqReplace = (hillsFreq <= 1.0 ) ? 1.0 : hillsFreq;
        
        dunesMagnReplace = 1.5;
        // Variation of hills height
        hillsMagnReplace = 1.0 / hillsFreqReplace;          //hillsMagn;
        // Flattens freckles
        flatHills = 1.0 / hillsFreqReplace;
        granNoise = 3.0;
    }
    
    // Flows
    noiseOctaves = 5;
    vec3  p = point * max(1.0, colorDistFreq) + Randomize;            // *** That's what matters.*** 
    // vec3  p = point * colorDistFreq + Randomize;
    vec3  dist = 2.5 * Fbm3D(p * 0.5);
    noiseOctaves = 3;
    float flows = Fbm(p * 7.5 + dist);
    
    // Granularity
    noiseOctaves = granNoise;
    p = point * hillsFreqReplace * flatHills + Randomize;
    dist = dunesMagnReplace * Fbm3D(p * 0.2);
    vec2  cell = Cell3Noise2(p + dist);
    float gran = smoothstep(0.1, 1.0, sqrt(abs(cell.y - cell.x))) - 0.5;

    // Solar spots
    float botMask = 1.0;
    float filMask = 0.0;
    float filaments = 0.0;
    if (mareSqrtDensity > 0.01)
    {
        noiseOctaves = 5;
        SolarSpotsHeightNoise(point, botMask, filMask, filaments);
    }

    const float surfHeight = 1.0;
    const float filHeight  = 0.6;
    const float spotHeight = 0.5;

    //return (0.8 + flows * 0.1) * colorDistMagn * botMask + gran * hillsMagn * (1.0 - filMask) + saturate(filaments) * 0.1 * hillsMagn * filMask;
        return (0.8 + flows * 0.1) * colorDistMagn * botMask + gran * hillsMagnReplace * (1.0 - filMask) + saturate(filaments) * 0.1 * hillsMagnReplace * filMask;
}

//-----------------------------------------------------------------------------

void main()
{
    vec3  point = GetSurfacePoint();
    float height = HeightMapSun(point);
    OutColor = vec4(height);
}

//-----------------------------------------------------------------------------

#endif
